@@ -178,3 +178,10 @@ bool Configuration::showPasswordDialog() const
 
     return true;
 }
+
+bool Configuration::systemConnectionsByDefault() const
+{
+    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("plasma-nm"));
+    KConfigGroup grp(config, QStringLiteral("General"));
+    return grp.readEntry(QStringLiteral("SystemConnectionsByDefault"), false);
+}
