@@ -72,6 +72,7 @@ void ConnectionEditorBase::setConnection(const NetworkManager::ConnectionSetting
     m_connection.clear();
     m_connection = connection;
     m_initialized = false;
+    m_wifiSecurity = nullptr;
 
     // Reset UI setting widgets
     delete m_connectionWidget;
@@ -255,7 +256,6 @@ void ConnectionEditorBase::initialize()
         auto wireGuardInterfaceWidget = new WireGuardInterfaceWidget(m_connection->setting(NetworkManager::Setting::WireGuard), this);
         addSettingWidget(wireGuardInterfaceWidget, i18n("WireGuard Interface"));
     } else if (type == NetworkManager::ConnectionSettings::Vpn) { // VPN
-        QString error;
         NetworkManager::VpnSetting::Ptr vpnSetting = m_connection->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
         if (!vpnSetting) {
             qCWarning(PLASMA_NM_EDITOR_LOG) << "Missing VPN setting!";
@@ -386,6 +386,7 @@ void ConnectionEditorBase::initialize()
                     connection->settings()->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
                 if (wifiSecuritySetting
                     && (wifiSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEap
+                        || wifiSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEapSuiteB192
                         || (wifiSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting::Ieee8021x
                             && wifiSecuritySetting->authAlg() != NetworkManager::WirelessSecuritySetting::Leap))) {
                     NetworkManager::Security8021xSetting::Ptr securitySetting =
