@@ -18,6 +18,7 @@
  */
 class ListValidator : public QValidator
 {
+    Q_OBJECT
 public:
     explicit ListValidator(QObject *parent);
     ~ListValidator() override;
@@ -26,7 +27,7 @@ public:
     void setInnerValidator(QValidator *validator);
 
 private:
-    QValidator *inner;
+    QValidator *inner = nullptr;
 };
 
 #endif // PLASMA_NM_LIST_VALIDATOR_H
