@@ -4,10 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #include "wireguardinterfacewidget.h"
-#include "plasma_nm_editor.h"
 #include "simpleiplistvalidator.h"
-#include "simpleipv4addressvalidator.h"
-#include "uiutils.h"
 #include "wireguardkeyvalidator.h"
 #include "wireguardtabwidget.h"
 
@@ -575,7 +572,7 @@ NMVariantMapMap WireGuardInterfaceWidget::importConnectionSettings(const QString
             return result;
         }
     }
-    if (!havePrivateKey || !haveAllowedIps || !havePublicKey || !haveAllowedIps)
+    if (!havePrivateKey || !haveAllowedIps || !havePublicKey)
         return result;
 
     QVariantMap conn;
