@@ -11,6 +11,7 @@
 
 class Q_DECL_EXPORT SimpleIpV6AddressValidator : public QValidator
 {
+    Q_OBJECT
 public:
     enum AddressStyle { Base, WithCidr, WithPort };
 
@@ -28,7 +29,7 @@ public:
     QValidator::State checkTetradsRanges(QString &) const;
 
 private:
-    AddressStyle m_addressStyle;
+    const AddressStyle m_addressStyle;
     QRegularExpressionValidator m_validator;
 };
 
