@@ -320,6 +320,7 @@ void OpenVpnSettingWidget::handleOnePasswordType(const PasswordField *passwordFi
 void OpenVpnSettingWidget::showAdvanced()
 {
     QPointer<OpenVpnAdvancedWidget> adv = new OpenVpnAdvancedWidget(d->setting, this);
+    adv->setAttribute(Qt::WA_DeleteOnClose);
     adv->init();
     connect(adv.data(), &OpenVpnAdvancedWidget::accepted, [adv, this]() {
         NetworkManager::VpnSetting::Ptr advData = adv->setting();
@@ -328,11 +329,6 @@ void OpenVpnSettingWidget::showAdvanced()
             d->setting->setSecrets(advData->secrets());
         }
     });
-    connect(adv.data(), &OpenVpnAdvancedWidget::finished, [adv]() {
-        if (adv) {
-            adv->deleteLater();
-        }
-    });
     adv->setModal(true);
     adv->show();
 }
